---
icon: lucide/paintbrush
---
# Identity

## Name

"Pydgey" (/ˈpɪdʒi/) is a portmanteau of *Python* and *Pidgey*. It has no conceptual connection to the Pokémon, it was chosen on a whim because I thought it would sound funny to say "Pydgey widget" (and [*Pidgey* was already taken](https://pypi.org/project/pidgey/)).

## Logo

The logo is a goofy rendition of the artwork for [Pidgey (#196/091)](https://pkmncards.com/card/pidgey-paldean-fates-paf-196/) from Scarlet & Violet — Paldean Fates, originally illustrated by [sowsow](https://x.com/sowsowkoubou), and published by The Pokémon Company.

The typeface is [Isobare](https://www.clemencefontaine.fr/page/isobar.html), designed by Clémence Fontaine and licensed under the [SIL Open Font License, Version 1.1](https://openfontlicense.org/).

<p align="center">
  <img src="../../static/pydgey-text.png" width="200" alt="Pydgey text">
</p>

<p align="center">
  <img src="../../static/pydgey-mascot.png" width="200" alt="Pydgey mascot">
</p>

<p align="center">
  <img src="../../static/pydgey-logo.png" width="200" alt="Pydgey logo">
</p>

<p align="center">
  <img src="../../static/pydgey-head.png" width="100" alt="Pydgey head">
</p>
